spannertools.find_index_of_spanner_component_at_score_offset
============================================================

.. autofunction:: abjad.tools.spannertools.find_index_of_spanner_component_at_score_offset.find_index_of_spanner_component_at_score_offset
